@@ -70,10 +70,11 @@ __all__ = [
 
 T = TypeVar("T")
 
+from envo.shell import Shell, ShellCodeError
+
 if TYPE_CHECKING:
     from envo import Plugin
     from envo.scripts import Status
-    from envo.shell import FancyShell, Shell
 
 
 class MagicFunctionData:
@@ -564,6 +565,8 @@ class ShellEnv:
     magic_functions: Dict[str, Any]
     env: Env
 
+    first_run = True
+
     def __init__(self, calls: _Callbacks, se: _Sets, li: _Links) -> None:
         self._calls = calls
         self._se = se
@@ -677,18 +680,22 @@ class ShellEnv:
 
             sw = Stopwatch()
             sw.start()
-            functions = self.magic_functions["onload"].values()
+            oncreate_funs = self.magic_functions["oncreate"].values()
+            onload_funs = self.magic_functions["onload"].values()
 
             self._start_reloaders()
 
             try:
-                for h in functions:
+                if self.first_run:
+                    for h in oncreate_funs:
+                        h()
+                for h in onload_funs:
                     h()
                 self._run_boot_codes()
-            except BaseException as e:
+            except ShellCodeError as e:
                 # TODO: pass env code to exception to get relevant traceback?
                 self._li.status.shell_context_ready = True
-                self._calls.on_error(e)
+                self._calls.on_error(e.exc, e.msg)
                 self._exit()
                 return
 
@@ -703,6 +710,7 @@ class ShellEnv:
 
             logger.debug("Finished load context thread")
             self._li.status.shell_context_ready = True
+            self.first_run = False
 
         if not self._se.blocking:
             Thread(target=thread, args=(self,)).start()
@@ -748,15 +756,6 @@ class ShellEnv:
 
         return shell_context
 
-    def on_shell_create(self) -> None:
-        """
-        Called only after creation.
-        :return:
-        """
-        functions = self.magic_functions["oncreate"].values()
-        for h in functions:
-            h()
-
     def _on_destroy(self) -> None:
         functions = self.magic_functions["ondestroy"]
         for h in functions.values():
