@@ -315,17 +315,21 @@ def add_source_roots(paths: List[Union[Path, str]]) -> None:
         sys.path.insert(0, str(p))
 
 
-def get_repo_root() -> Path:
+def get_src_root(name: str) -> Path:
     path = Path(".").absolute()
 
-    while not list(path.glob("*.git")):
+    while not list(path.glob(f"*{name}")):
         if path == path.parent:
-            raise RuntimeError("Can't find repo root (missing .git directory?)")
+            raise RuntimeError(f'Cannot find src root (missing "{name}" file?)')
         path = path.parent
 
     return path
 
 
+def get_repo_root() -> Path:
+    return get_src_root(".git")
+
+
 def iterate_frames(frame: FrameType) -> Generator[FrameType, None, None]:
     current_frame: Optional[FrameType] = frame
     while current_frame:
@@ -333,11 +337,6 @@ def iterate_frames(frame: FrameType) -> Generator[FrameType, None, None]:
         current_frame = current_frame.f_back
 
 
-def is_suspend_frame(frame: FrameType) -> bool:
-    ret = "pydevd.py" in frame.f_code.co_filename and "do_wait_suspend" in frame.f_code.co_name
-    return ret
-
-
 def colored(inp: str, color: Tuple[int, int, int]) -> str:
     ret = f"\033[38;2;{color[0]};{color[1]};{color[2]}m{inp}\x1b[0m"
     return ret
